==> apache-wicket-6.30.0.zip: apache-wicket-6.30.0/wicket-experimental/wicket-atmosphere/src/main/java/org/apache/wicket/atmosphere/JQueryWicketAtmosphereResourceReference.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.wicket.atmosphere;

import java.util.Arrays;

import de.agilecoders.wicket.webjars.request.resource.WebjarsJavaScriptResourceReference;
import org.apache.wicket.markup.head.HeaderItem;
import org.apache.wicket.markup.head.JavaScriptHeaderItem;
import org.apache.wicket.resource.JQueryPluginResourceReference;

/**
 * Resource reference for the jquery.atmosphere.js module and the wicket glue.
 * 
 * @author papegaaij
 */
public class JQueryWicketAtmosphereResourceReference extends JQueryPluginResourceReference
{
	private static final long serialVersionUID = 1L;

	private static final JQueryWicketAtmosphereResourceReference INSTANCE = new JQueryWicketAtmosphereResourceReference();

	/**
	 * @return the singleton instance of this resource reference.
	 */
	public static JQueryWicketAtmosphereResourceReference get()
	{
		return INSTANCE;
	}

	private JQueryWicketAtmosphereResourceReference()
	{
		super(JQueryWicketAtmosphereResourceReference.class, "jquery.wicketatmosphere.js");
	}

	@Override
	public Iterable<? extends HeaderItem> getDependencies()
	{
		WebjarsJavaScriptResourceReference jqueryAtmosphereReference = new WebjarsJavaScriptResourceReference("jquery-atmosphere/current/jquery.atmosphere.js");
		return Arrays.asList(JavaScriptHeaderItem.forReference(jqueryAtmosphereReference));
	}
}

==> apache-wicket-7.18.0.zip: apache-wicket-7.18.0/wicket-experimental/wicket-atmosphere/src/main/java/org/apache/wicket/atmosphere/JQueryWicketAtmosphereResourceReference.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.wicket.atmosphere;

import java.util.List;

import org.apache.wicket.markup.head.HeaderItem;
import org.apache.wicket.markup.head.JavaScriptHeaderItem;
import org.apache.wicket.resource.JQueryPluginResourceReference;

import de.agilecoders.wicket.webjars.request.resource.WebjarsJavaScriptResourceReference;

/**
 * Resource reference for the jquery.atmosphere.js module and the wicket glue.
 * 
 * @author papegaaij
 */
public class JQueryWicketAtmosphereResourceReference extends JQueryPluginResourceReference
{
	private static final long serialVersionUID = 1L;

	private static final JQueryWicketAtmosphereResourceReference INSTANCE = new JQueryWicketAtmosphereResourceReference();

	/**
	 * @return the singleton instance of this resource reference.
	 */
	public static JQueryWicketAtmosphereResourceReference get()
	{
		return INSTANCE;
	}

	private JQueryWicketAtmosphereResourceReference()
	{
		super(JQueryWicketAtmosphereResourceReference.class, "jquery.wicketatmosphere.js");
	}

	@Override
	public List<HeaderItem> getDependencies()
	{
		List<HeaderItem> dependencies = super.getDependencies();
		WebjarsJavaScriptResourceReference jqueryAtmosphereReference = new WebjarsJavaScriptResourceReference("jquery-atmosphere/current/jquery.atmosphere.js");
		dependencies.add(JavaScriptHeaderItem.forReference(jqueryAtmosphereReference));
		return dependencies;
	}
}
